@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "الملاحظات",
     "New note" : "ملاحظة جديدة ",
+    "Error" : "خطأ",
     "Settings" : "الإعدادات",
     "Categories" : "الفئات",
     "Today" : "اليوم",
@@ -12,10 +13,15 @@ OC.L10N.register(
     "This month" : "هذا الشهر",
     "Last month" : "الشهر الماضي",
     "Delete note" : "حذف الملاحظة ",
+    "Remove from favorites" : "إزالتها مِن المفضلة",
+    "Add to favorites" : "أضفه إلى المفضلة",
     "Details" : "التفاصيل",
     "Preview" : "معاينة",
+    "Edit" : "تعديل",
     "Category" : "الفئة",
     "Saving failed!" : "فشلت عملية الحفظ !",
-    "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"]
+    "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"],
+    "Android app" : "تطبيق الأندرويد",
+    "iOS app" : "تطبيق آي أواس"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
