@@ -10,7 +10,9 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
+    "Last week" : "Semana pasada",
     "This month" : "Este mes",
+    "Last month" : "Mes pasado",
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
@@ -18,6 +20,7 @@ OC.L10N.register(
     "Preview" : "Vista previa",
     "Edit" : "Editar",
     "Category" : "Categoría",
+    "Uncategorized" : "Sin categoría",
     "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS"
