@@ -5,8 +5,9 @@ OC.L10N.register(
     "New note" : "Ohar berria",
     "Encryption Error" : "Zifratze errorea",
     "Error" : "Errorea",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko notak daude. Orrialdetik irtetzean aldaketa guztiak galduko dira!",
     "Settings" : "Ezarpenak",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko notak daude. Orrialdetik irtetzean aldaketa guztiak galduko dira!",
+    "Folder to store your notes" : "Zure oharrak gordetzeko karpeta",
     "path to notes" : "oharretara bidea",
     "All notes" : "Ohar guztiak",
     "Categories" : "Kategoriak",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "This month" : "Hilabete honetan",
     "Last month" : "Azken hilabetean",
     "Delete note" : "Ezabatu oharra",
+    "Deleted {title}" : "{title} ezabatuta",
     "Remove from favorites" : "Kendu gogokoetatik",
     "Add to favorites" : "Gehitu gogokoetan",
     "Empty note" : "Ohar hutsa",
@@ -31,6 +33,7 @@ OC.L10N.register(
     "Set category" : "Ezarri kategoria",
     "Category" : "Kategoria",
     "Uncategorized" : "Sailkatu gabe",
+    "Click here to save manually" : "Sakatu hemen eskuz gordetzeko",
     "Saving failed!" : "Gordetzean errorea!",
     "Subcategory" : "Azpikategoria",
     "_%n word_::_%n words_" : ["%n hitz","%n hitz"],
