@@ -6,10 +6,12 @@ use OCP\AppFramework\Controller;
 use OCP\IRequest;
 use OCP\IConfig;
 use OCP\IL10N;
+use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
 
 use OCA\Notes\Service\NotesService;
 use OCA\Notes\Service\SettingsService;
+use OCA\Notes\Service\InsufficientStorageException;
 
 /**
  * Class NotesController
@@ -62,7 +64,6 @@ class NotesController extends Controller {
 	 * @NoAdminRequired
 	 */
 	public function index() {
-		$notes = $this->notesService->getAll($this->userId, true);
 		$settings = $this->settingsService->getAll($this->userId);
 
 		$errorMessage = null;
@@ -72,8 +73,9 @@ class NotesController extends Controller {
 			'notesLastViewedNote'
 		);
 		// check if notes folder is accessible
+		$notes = null;
 		try {
-			$this->notesService->checkNotesFolder($this->userId);
+			$notes = $this->notesService->getAll($this->userId, true);
 			if ($lastViewedNote) {
 				// check if note exists
 				try {
@@ -112,9 +114,8 @@ class NotesController extends Controller {
 			$id
 		);
 
-		return $this->respond(function () use ($id) {
-			return $this->notesService->get($id, $this->userId);
-		});
+		$note = $this->notesService->get($id, $this->userId);
+		return new DataResponse($note);
 	}
 
 
@@ -124,14 +125,18 @@ class NotesController extends Controller {
 	 * @param string $content
 	 */
 	public function create($content = '', $category = null) {
-		$note = $this->notesService->create($this->userId);
-		$note = $this->notesService->update(
-			$note->getId(),
-			$content,
-			$this->userId,
-			$category
-		);
-		return new DataResponse($note);
+		try {
+			$note = $this->notesService->create($this->userId);
+			$note = $this->notesService->update(
+				$note->getId(),
+				$content,
+				$this->userId,
+				$category
+			);
+			return new DataResponse($note);
+		} catch (InsufficientStorageException $e) {
+			return new DataResponse([], Http::STATUS_INSUFFICIENT_STORAGE);
+		}
 	}
 
 
@@ -143,9 +148,12 @@ class NotesController extends Controller {
 	 * @return DataResponse
 	 */
 	public function update($id, $content) {
-		return $this->respond(function () use ($id, $content) {
-			return $this->notesService->update($id, $content, $this->userId);
-		});
+		try {
+			$note = $this->notesService->update($id, $content, $this->userId);
+			return new DataResponse($note);
+		} catch (InsufficientStorageException $e) {
+			return new DataResponse([], Http::STATUS_INSUFFICIENT_STORAGE);
+		}
 	}
 
 
@@ -158,10 +166,8 @@ class NotesController extends Controller {
 	 * @return DataResponse
 	 */
 	public function category($id, $category) {
-		return $this->respond(function () use ($id, $category) {
-			$note = $this->notesService->update($id, null, $this->userId, $category);
-			return $note->category;
-		});
+		$note = $this->notesService->update($id, null, $this->userId, $category);
+		return new DataResponse($note->category);
 	}
 
 
@@ -173,9 +179,8 @@ class NotesController extends Controller {
 	 * @return DataResponse
 	 */
 	public function favorite($id, $favorite) {
-		return $this->respond(function () use ($id, $favorite) {
-			return $this->notesService->favorite($id, $favorite, $this->userId);
-		});
+		$result = $this->notesService->favorite($id, $favorite, $this->userId);
+		return new DataResponse($result);
 	}
 
 
@@ -186,9 +191,7 @@ class NotesController extends Controller {
 	 * @return DataResponse
 	 */
 	public function destroy($id) {
-		return $this->respond(function () use ($id) {
-			$this->notesService->delete($id, $this->userId);
-			return [];
-		});
+		$this->notesService->delete($id, $this->userId);
+		return new DataResponse([]);
 	}
 }
