@@ -126,9 +126,7 @@ class NotesService {
 	public function create($userId) : Note {
 		$title = $this->l10n->t('New note');
 		$folder = $this->getFolderForUser($userId);
-		if ($folder->getFreeSpace() <= 1) {
-			throw new InsufficientStorageException();
-		}
+		$this->noteUtil->ensureSufficientStorage($folder, 1);
 
 		// check new note exists already and we need to number it
 		// pass -1 because no file has id -1 and that will ensure
@@ -183,9 +181,7 @@ class NotesService {
 		}
 
 		if ($content !== null) {
-			if ($file->getParent()->getFreeSpace() < strlen($content)) {
-				throw new InsufficientStorageException();
-			}
+			$this->noteUtil->ensureSufficientStorage($file->getParent(), strlen($content));
 			$file->putContent($content);
 		}
 
